Topic
=====

.. The line below adds a local TOC

.. contents:: :local:
  :depth: 1

Recipe Title
------------

Objective
^^^^^^^^^

(Objective Text)

Solution
^^^^^^^^

.. code-block:: codeType

  (add code here - note the empty line above and below)

Explanation
^^^^^^^^^^^

(add explanation here)

.. End of <RECIPE TITLE>
